class Result:
    def __init__(self, database=None, params=None, elapsed=None, test=None):
        self.database = database
        self.params = params
        self.elapsed = elapsed
        self.test = test
